summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilotAddress.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilotAddress.h')
-rw-r--r--kpilot/lib/pilotAddress.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kpilot/lib/pilotAddress.h b/kpilot/lib/pilotAddress.h
index d6dd20e4..5bd0a1e0 100644
--- a/kpilot/lib/pilotAddress.h
+++ b/kpilot/lib/pilotAddress.h
@@ -33,7 +33,7 @@
#include <pi-macros.h>
#include <pi-address.h>
-#include <qnamespace.h>
+#include <tqnamespace.h>
#include "pilotRecord.h"
#include "pilotAppInfo.h"
@@ -119,7 +119,7 @@ public:
return (entryPhone1 <= i) && (i <= entryPhone5);
}
- operator QString() const;
+ operator TQString() const;
private:
int i;
} ;
@@ -150,7 +150,7 @@ public:
eNone=-1
} ;
- QString phoneLabel(EPhoneType i) const;
+ TQString phoneLabel(EPhoneType i) const;
} ;
/** @brief A wrapper class around the Address struct provided by pi-address.h
@@ -202,7 +202,7 @@ public:
* is used to figure out the phone labels; if it is NULL then bogus labels are
* used to identify phone types.
*/
- QString getTextRepresentation(const PilotAddressInfo *info, Qt::TextFormat richText) const;
+ TQString getTextRepresentation(const PilotAddressInfo *info, Qt::TextFormat richText) const;
/**
* @param text set the field value
@@ -215,9 +215,9 @@ public:
* entryTitle, entryCustom1, entryCustom2, entryCustom3, entryCustom4,
* entryNote };
*/
- void setField(int field, const QString &text);
+ void setField(int field, const TQString &text);
/** Set a field @p i to a given text value. Uses the phone slots only. */
- void setField(const PhoneSlot &i, const QString &t)
+ void setField(const PhoneSlot &i, const TQString &t)
{
if (i.isValid())
{
@@ -225,22 +225,22 @@ public:
}
}
/** Returns the text value of a given field @p field (or QString::null
* if there is no such field).
*/
- QString getField(int field) const;
+ TQString getField(int field) const;
/** Returns the value of the phone field @p i . */
- QString getField(const PhoneSlot &i) const
+ TQString getField(const PhoneSlot &i) const
{
- return i.isValid() ? getField(i.toField()) : QString();
+ return i.isValid() ? getField(i.toField()) : TQString();
}
/**
* Return list of all email addresses. This will search through our "phone"
* fields and will return only those which are e-mail addresses.
*/
- QStringList getEmails() const;
- void setEmails(const QStringList &emails);
+ TQStringList getEmails() const;
+ void setEmails(const TQStringList &emails);
enum PhoneHandlingFlags
{
@@ -254,7 +254,7 @@ public:
* for extra phone fields
* @return the field associated with the type
*/
- QString getPhoneField(PilotAddressInfo::EPhoneType type) const;
+ TQString getPhoneField(PilotAddressInfo::EPhoneType type) const;
/**
* @param type is the type of phone
@@ -265,7 +265,7 @@ public:
* with the field, else it will always search for the first available slot
* @return index of the field that this information was set to
*/
- PhoneSlot setPhoneField(PilotAddressInfo::EPhoneType type, const QString &value, PhoneHandlingFlags flags);
+ PhoneSlot setPhoneField(PilotAddressInfo::EPhoneType type, const TQString &value, PhoneHandlingFlags flags);
/**
* Returns the slot of the phone number
@@ -225,22 +225,22 @@ public:
}
}
- /** Returns the text value of a given field @p field (or QString::null
+ /** Returns the text value of a given field @p field (or TQString::null
* if there is no such field).
*/